==> manim_slides-5.1.7.tar.gz: manim_slides-5.1.7/docs/source/gallery.md <==
# Examples Gallery

With Manim, the only limit to what you can create is your imagination!
*This also applies to Manim Slides.*

As the field of possibilities is infinitely vast,
it's often useful to **learn** how to use Manim Slides **based on examples**.

The aim of this page is to share with you the creations of some
Manim Slides users, to hopefully inspire you!
Most of them use HTML conversion to make them accessible via a website.

If you too have created content with Manim Slides that is available online
(e.g., a YouTube video or website),
don't hesitate to contact us so that we can share your content on this page!

## Scientif Research

Below are people that dissimenate their research results
using Manim Slides presentations.

### Daniel Panizo Pérez

Daniel publishes his presentations on *Cosmology, String Theory and related*
topics on his
[personal website](https://panopepino.github.io/web_page/main_page/slides.html).

For example, below are the slides of a seminar he gave titled
[Our Universe on a (Dark) Bubble](https://panopepino.github.io/web_page/main_page/presentations/2023_11_long/LS.html).

<div style="position:relative;padding-bottom:56.25%;">
    <iframe
        loading="lazy"
        style="width:100%;height:100%;position:absolute;left:0px;top:0px;"
        frameborder="1"
        width="100%"
        height="100%"
        allowfullscreen
        allow="autoplay"
        src="https://panopepino.github.io/web_page/main_page/presentations/2023_11_long/LS.html">
    </iframe>
</div>

He also shares his code on a public
[GitHub repository](https://github.com/PanoPepino/Manim_Theoretical).

### Jérome Eertmans

Jérome, the author of Manim Slides, publishes his presentations
on the topic of *Ray Tracing applied to Radio Propagations* on his
[personal website](https://eertmans.be). He also uses Manim Slides
for presenting at conferences using the *PowerPoint* or HTML conversion.

For example, below are the slides of his
[PhD confirmation](https://eertmans.be/posts/confirmation2023-presentation/).

<div style="position:relative;padding-bottom:56.25%;">
    <iframe
        loading="lazy"
        style="width:100%;height:100%;position:absolute;left:0px;top:0px;"
        frameborder="1"
        width="100%"
        height="100%"
        allowfullscreen
        allow="autoplay"
        src="https://eertmans.be/assets/slides/2023-12-07-confirmation.html">
    </iframe>
</div>

## School Work

Below are people that used Manim Slides for school presentations.

*This list is currently empty. Please reach out to us if you have examples
to share!*

==> manim_slides-5.5.0.tar.gz: manim_slides-5.5.0/docs/source/gallery.md <==
# Examples Gallery

With Manim, the only limit to what you can create is your imagination!
*This also applies to Manim Slides.*

As the field of possibilities is infinitely vast,
it's often useful to **learn** how to use Manim Slides **based on examples**.

The aim of this page is to share with you the creations of some
Manim Slides users, to hopefully inspire you!
Most of them use HTML conversion to make them accessible via a website.

If you too have created content with Manim Slides that is available online
(e.g., a YouTube video or website),
don't hesitate to contact us so that we can share your content on this page!

## Scientif Research

Below are people that dissimenate their research results
using Manim Slides presentations.

### Daniel Panizo Pérez

Daniel publishes his presentations on *Cosmology, String Theory and related*
topics on his
[personal website](https://panopepino.github.io/web_page/main_page/slides.html). https://panopepino.github.io/web_page/main_page/slides.html

For example, below are the slides of a seminar he gave titled
[Our Universe on a (Dark) Bubble](https://panopepino.github.io/web_page/main_page/presentations/2023_11_long/LS.html).

<div style="position:relative;padding-bottom:56.25%;">
    <iframe
        loading="lazy"
        style="width:100%;height:100%;position:absolute;left:0px;top:0px;"
        frameborder="1"
        width="100%"
        height="100%"
        allowfullscreen
        allow="autoplay"
        src="https://panopepino.github.io/web_page/main_page/presentations/2023_11_long/LS.html">
    </iframe>
</div>

He also shares his code on a public
[GitHub repository](https://github.com/PanoPepino/mtheoretical).

### Jérome Eertmans

Jérome, the author of Manim Slides, publishes his presentations
on the topic of *Ray Tracing applied to Radio Propagations* on his
[personal website](https://eertmans.be). He also uses Manim Slides
for presenting at conferences using the *PowerPoint* or HTML conversion.

For example, below are the slides of his
[PhD confirmation](https://eertmans.be/posts/confirmation2023-presentation/).

<div style="position:relative;padding-bottom:56.25%;">
    <iframe
        loading="lazy"
        style="width:100%;height:100%;position:absolute;left:0px;top:0px;"
        frameborder="1"
        width="100%"
        height="100%"
        allowfullscreen
        allow="autoplay"
        src="https://eertmans.be/assets/slides/2023-12-07-confirmation.html">
    </iframe>
</div>

## School Work

Below are people that used Manim Slides for school presentations.

*This list is currently empty. Please reach out to us if you have examples
to share!*
